timeseries.SpaceCurve.slide — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.slide

`SpaceCurve.` `slide`(window=60000000000, time_step=1000000000, time_start=None, time_stop=None, overlap_ends=True)

  Produce equal-time SpaceCurves using a sliding-window on self.

  Parameters: | window : int length of window in nanoseconds (default = 60*10**9 or 1 minute) time_step : int step size in nanoseconds between window starting-points (default = 1*10** or 1 second) time_start : int start time in nanoseconds (default = None, min time) time_stop : int stop time in nanoseconds (default = None, max time) overlap_ends : bool Should endpoints overlap (True) or abutt (False) (default = True)
  Returns: | iterator of SpaceCurves To access the tracks as a list, do :code:`list( FT.snip() )`

  Notes

  The trackids are unchanged! You might want to change them manually.

#### Previous topic

timeseries.SpaceCurve.signature_curve

#### Next topic

timeseries.SpaceCurve.snip